@@ -2,3 +2,5 @@ class Services:
     MOVIES_SEARCH_SERVICE: str = "movies_search_service"
     PROXY_AUTH_SERVICE: str = "proxy_auth_service"
     MOVIES_ADMIN_PANEL_SERVICE: str = "movies_admin_panel_service"
+    MOVIES_UGC_SERVICE: str = "movies_ugc_service"
+    MOVIES_NOTIFICATION_SERVICE: str = "movies_notification_service"
